Disk

Struct Disk 

pub struct Disk { /* private fields */ }
A disk device with a cursor.

Implementations

Source

impl Disk

pub fn new(dev: AxBlockDevice) -> Self

Create a new disk.

pub fn size(&self) -> u64

Get the size of the disk.

pub fn position(&self) -> u64

Get the position of the cursor.

pub fn set_position(&mut self, pos: u64)

Set the position of the cursor.

pub fn read_one(&mut self, buf: &mut [u8]) -> DevResult<usize>

Read within one block, returns the number of bytes read.

pub fn write_one(&mut self, buf: &[u8]) -> DevResult<usize>

Write within one block, returns the number of bytes written.