Partition

Struct Partition 

pub struct Partition { /* private fields */ }
A partition wrapper that provides access to a specific partition of a disk.

Implementations

Source

impl Partition

pub fn new(disk: Disk, start_lba: u64, end_lba: u64) -> Self

Create a new partition wrapper.

pub fn size(&self) -> u64

Get the size of the partition.

pub fn position(&self) -> u64

Get the position of the cursor.

pub fn set_position(&mut self, pos: u64)

Set the position of the cursor.

pub fn read_one(&mut self, buf: &mut [u8]) -> DevResult<usize>

Read within one block, returns the number of bytes read.

pub fn write_one(&mut self, buf: &[u8]) -> DevResult<usize>

Write within one block, returns the number of bytes written.